@@ -2,11 +2,10 @@ import singlecellexperiment
 import numpy as np
 from random import random
 import pandas as pd
-from genomicranges import GenomicRanges
+import genomicranges
 from singlecellexperiment.SingleCellExperiment import SingleCellExperiment
 
 import anndata
-import pytest
 
 __author__ = "jkanche"
 __copyright__ = "jkanche"
@@ -39,7 +38,7 @@ df_gr = pd.DataFrame(
     }
 )
 
-gr = GenomicRanges.fromPandas(df_gr)
+gr = genomicranges.fromPandas(df_gr)
 
 colData = pd.DataFrame({"treatment": ["ChIP", "Input"] * 3,})
 
